@@ -4,6 +4,7 @@ import pymysql
 import datetime as dt
 import sys
 from slacker import Slacker
+from skpy import Skype
 
 
 class KonnectiveToolbox:
@@ -79,6 +80,76 @@ class KonnectiveToolbox:
         return value
 
 
+class ClickBank:
+    def __init__(self, base_url, endpoint, developer_key, clerk_key):
+        self.base_url = base_url
+        self.endpoint = endpoint
+        self.developer_key = developer_key
+        self.clerk_key = clerk_key
+        self.headers = {'Accept': 'application/json', 'Authorization': f'{self.developer_key}:{self.clerk_key}'}
+
+    def create_url(self, method, **params):
+        url = f'{self.base_url}{self.endpoint}/{method}'.replace('//', '/').replace('https:/', 'https://')
+        parameters = '&'.join([f'{param}={params[param]}' for param in params])
+        return '?'.join([url, parameters])
+
+    def get_json(self, url, get_all=True):
+        page = 0
+        headers = self.headers
+
+        _list = []
+
+        while True:
+            page += 1
+            headers['page'] = str(page)
+            print(f'{url} - page: {page}')
+            r = requests.get(url, headers=headers)
+            _json = r.json()
+
+            if 'orders2' in self.endpoint:
+                if _json is not None:
+                    for data in _json['orderData']:
+                        _list.append(data)
+                else:
+                    break
+
+                if not get_all:
+                    break
+
+            if 'analytics' in self.endpoint:
+                try:
+                    for data in _json['rows']['row']:
+                        _list.append(data)
+                except TypeError:
+                    break
+
+                if not get_all:
+                    break
+
+        return _list
+
+    def check_if_null(self, _value, string=True):
+        if _value is None:
+            return 'NULL'
+
+        if isinstance(_value, dict):
+            _value = 'NULL'
+        else:
+            _value = f'"{_value}"' if string else _value
+
+        return _value
+
+
+class EarnwareToolbox:
+    def __init__(self, userId):
+        self.userId = userId
+        self.headers = {'Content-Type': 'application/json'}
+
+    def upload_to_contacts(self, url, payload):
+        r = requests.post(url, payload, headers=self.headers)
+        return r
+
+
 class OntraportToolbox:
     def __init__(self, version=1, api_key='', api_appid=''):
         self.version = version
@@ -98,6 +169,12 @@ class OntraportToolbox:
         print(f'Response: {r.status_code} {r.reason} | URL: {url}')
         return r
 
+    def convert_date_to_epoch(self, _my_datetime):
+        if isinstance(_my_datetime, dt.datetime):
+            return _my_datetime.timestamp()
+        else:
+            raise Exception('Invalid datetime provided.')
+
 
 class MySQLToolbox:
     def __init__(self, sqlPath, host, user, password, db):
@@ -149,7 +226,7 @@ class MySQLToolbox:
             return 'INSERT INTO {}.{} VALUES\n{}'.format(self.db, table, values)
 
     def stringfy(self, _string):
-        if _string is None or _string == '' or _string == 'NULL':
+        if _string is None or _string == '' or _string == 'NULL' or _string == 'None':
             return 'NULL'
         else:
             if "'" in _string:
@@ -174,7 +251,6 @@ class MySQLToolbox:
             raise Exception(err)
 
 
-
 class slackToolbox:
     def __init__(self, _key, _channel):
         self._key = _key
@@ -191,3 +267,21 @@ class slackToolbox:
         _message = f'Information: {description}'
         slack = Slacker(self._key)
         slack.chat.post_message(self._channel, _message)
+
+
+class SkypeToolbox:
+    def __init__(self, username, password, channel):
+        self.username = username
+        self.password = password
+        self.channel = channel
+        self.sk = Skype(username, password)
+        self.channel = self.sk.chats.chat(self.channel)
+
+    def send_message(self, filename=None, function=None, message=None):
+        if filename is None or function is None or message is None:
+            raise Exception('Please provide valid filename, function name, and message...')
+
+        message_format = f'Filename:\n\t{filename}\n' \
+                         f'Function Name:\n\t{function}\n' \
+                         f'Description:\n\t{message}\n{"=" * 78}'
+        self.channel.sendMsg(message_format)
